pub enum NameError {
LabelLength(usize),
LabelContent,
NameLength(usize),
}Expand description
An error was encountered when trying to work with a domain name
Variants
LabelLength(usize)
Some label in the DNS packet it too long, overflowing the packet or not following the DNS specification.
LabelContent
Some label in one of the domain names is not valid because it contains characters that are not alphanumeric or -.
NameLength(usize)
One of the labels in the packet has a length that is bigger than the DNS specification.