ResourceRecord

Struct ResourceRecord 

pub struct ResourceRecord<'a> {
    pub preamble: RecordPreamble<'a>,
    pub data: RecordData<'a>,
}
A description of a resource that can be used as an answer to a question or to provide additional information in the authority or additional fields of a DNS packet.

   +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
   |                                               |
   /                                               /
   /                      NAME                     /
   |                                               |
   +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
   |                      TYPE                     |
   +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
   |                     CLASS                     |
   +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
   |                      TTL                      |
   |                                               |
   +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
   |                   RDLENGTH                    |
   +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--|
   /                     RDATA                     /
   /                                               /
   +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+

Fields

preamble: RecordPreamble<'a>

Contains general information that every ResourceRecord shares, like type or class.

data: RecordData<'a>

The RDATA section of a resource record in some DNS packet.

Implementations

Source

impl<'a> ResourceRecord<'a>

pub fn parse(buff: &'a [u8], pos: usize) -> Result<(Self, usize), ParseError>

Parse from the specified buff, starting at position pos.

pub fn serialize(&self, packet: &mut Vec<u8>)

Serialize the ResourceRecord and append it tho the end of the provided packet